OctaStar. Elements
(octa_star v0.1.0)
Datastar datastar-patch-elements helpers.
Summary
Functions
Formats an element patch event without writing to a connection.
Formats an element removal event without writing to a connection.
Sends HTML elements to the browser for DOM patching.
Sends an element removal patch.
Functions
Formats an element patch event without writing to a connection.
Formats an element removal event without writing to a connection.
@spec patch(Plug.Conn.t(), iodata() | tuple() | nil, keyword()) :: Plug.Conn.t()
Sends HTML elements to the browser for DOM patching.
@spec remove(Plug.Conn.t(), String.t(), keyword()) :: Plug.Conn.t()
Sends an element removal patch.